@@ -40,11 +40,28 @@ bool FrameData::create(const x265_param& param, const SPS& sps, int csp)
     m_spsrpsIdx = -1;
     if (param.rc.bStatWrite)
         m_spsrps = const_cast<RPS*>(sps.spsrps);
-
-    m_cuMemPool.create(0, param.internalCsp, sps.numCUsInFrame);
-    for (uint32_t ctuAddr = 0; ctuAddr < sps.numCUsInFrame; ctuAddr++)
-        m_picCTU[ctuAddr].initialize(m_cuMemPool, 0, param.internalCsp, ctuAddr);
-
+    bool isallocated = m_cuMemPool.create(0, param.internalCsp, sps.numCUsInFrame, param);
+    if (m_param->bDynamicRefine)
+    {
+        CHECKED_MALLOC_ZERO(m_cuMemPool.dynRefineRdBlock, uint64_t, MAX_NUM_DYN_REFINE * sps.numCUsInFrame);
+        CHECKED_MALLOC_ZERO(m_cuMemPool.dynRefCntBlock, uint32_t, MAX_NUM_DYN_REFINE * sps.numCUsInFrame);
+        CHECKED_MALLOC_ZERO(m_cuMemPool.dynRefVarBlock, uint32_t, MAX_NUM_DYN_REFINE * sps.numCUsInFrame);
+    }
+    if (isallocated)
+    {
+        for (uint32_t ctuAddr = 0; ctuAddr < sps.numCUsInFrame; ctuAddr++)
+        {
+            if (m_param->bDynamicRefine)
+            {
+                m_picCTU[ctuAddr].m_collectCURd = m_cuMemPool.dynRefineRdBlock + (ctuAddr * MAX_NUM_DYN_REFINE);
+                m_picCTU[ctuAddr].m_collectCUVariance = m_cuMemPool.dynRefVarBlock + (ctuAddr * MAX_NUM_DYN_REFINE);
+                m_picCTU[ctuAddr].m_collectCUCount = m_cuMemPool.dynRefCntBlock + (ctuAddr * MAX_NUM_DYN_REFINE);
+            }
+            m_picCTU[ctuAddr].initialize(m_cuMemPool, 0, param, ctuAddr);
+        }
+    }
+    else
+        return false;
     CHECKED_MALLOC_ZERO(m_cuStat, RCStatCU, sps.numCUsInFrame);
     CHECKED_MALLOC(m_rowStat, RCStatRow, sps.numCuInHeight);
     reinit(sps);
@@ -64,6 +81,12 @@ void FrameData::reinit(const SPS& sps)
 {
     memset(m_cuStat, 0, sps.numCUsInFrame * sizeof(*m_cuStat));
     memset(m_rowStat, 0, sps.numCuInHeight * sizeof(*m_rowStat));
+    if (m_param->bDynamicRefine)
+    {
+        memset(m_picCTU->m_collectCURd, 0, MAX_NUM_DYN_REFINE * sizeof(uint64_t));
+        memset(m_picCTU->m_collectCUVariance, 0, MAX_NUM_DYN_REFINE * sizeof(uint32_t));
+        memset(m_picCTU->m_collectCUCount, 0, MAX_NUM_DYN_REFINE * sizeof(uint32_t));
+    }
 }
 
 void FrameData::destroy()
@@ -74,18 +97,20 @@ void FrameData::destroy()
 
     m_cuMemPool.destroy();
 
+    if (m_param->bDynamicRefine)
+    {
+        X265_FREE(m_cuMemPool.dynRefineRdBlock);
+        X265_FREE(m_cuMemPool.dynRefCntBlock);
+        X265_FREE(m_cuMemPool.dynRefVarBlock);
+    }
     X265_FREE(m_cuStat);
     X265_FREE(m_rowStat);
-
-    if (m_meBuffer)
+    for (int i = 0; i < INTEGRAL_PLANE_NUM; i++)
     {
-        for (int i = 0; i < INTEGRAL_PLANE_NUM; i++)
+        if (m_meBuffer[i] != NULL)
         {
-            if (m_meBuffer[i] != NULL)
-            {
-                X265_FREE(m_meBuffer[i]);
-                m_meBuffer[i] = NULL;
-            }
+            X265_FREE(m_meBuffer[i]);
+            m_meBuffer[i] = NULL;
         }
     }
 }
