@@ -169,6 +169,7 @@ public:
     Frame*             m_exportedPic;
     FILE*              m_analysisFileIn;
     FILE*              m_analysisFileOut;
+    FILE*              m_naluFile;
     x265_param*        m_param;
     x265_param*        m_latestParam;     // Holds latest param during a reconfigure
     RateControl*       m_rateControl;
@@ -212,6 +213,7 @@ public:
     double                m_cR;
 
     int                     m_bToneMap; // Enables tone-mapping
+    int                     m_enableNal;
 
 #ifdef ENABLE_HDR10_PLUS
     const hdr10plus_api     *m_hdr10plus_api;
@@ -273,13 +275,7 @@ public:
 
     void updateVbvPlan(RateControl* rc);
 
-    void allocAnalysis(x265_analysis_data* analysis);
-
-    void freeAnalysis(x265_analysis_data* analysis);
-
-    void allocAnalysis2Pass(x265_analysis_2Pass* analysis, int sliceType);
-
-    void freeAnalysis2Pass(x265_analysis_2Pass* analysis, int sliceType);
+    void readAnalysisFile(x265_analysis_data* analysis, int poc, int sliceType);
 
     void readAnalysisFile(x265_analysis_data* analysis, int poc, const x265_picture* picIn, int paramBytes);
 
@@ -289,13 +285,16 @@ public:
 
     int getPuShape(puOrientation* puOrient, int partSize, int numCTU);
 
-    void writeAnalysisFile(x265_analysis_data* pic, FrameData &curEncData);
-    void readAnalysis2PassFile(x265_analysis_2Pass* analysis2Pass, int poc, int sliceType);
-    void writeAnalysis2PassFile(x265_analysis_2Pass* analysis2Pass, FrameData &curEncData, int slicetype);
+    void writeAnalysisFile(x265_analysis_data* analysis, FrameData &curEncData);
+
+    void writeAnalysisFileRefine(x265_analysis_data* analysis, FrameData &curEncData);
+
     void finishFrameStats(Frame* pic, FrameEncoder *curEncoder, x265_frame_stats* frameStats, int inPoc);
 
     int validateAnalysisData(x265_analysis_data* analysis, int readWriteFlag);
 
+    void readUserSeiFile(x265_sei_payload& seiMsg, int poc);
+
     void calcRefreshInterval(Frame* frameEnc);
 
     void initRefIdx();
@@ -303,6 +302,8 @@ public:
     void updateRefIdx();
     bool computeSPSRPSIndex();
 
+    void copyUserSEIMessages(Frame *frame, const x265_picture* pic_in);
+
 protected:
 
     void initVPS(VPS *vps);
